@@ -1,9 +1,9 @@
 package JSONY::Grammar;
 use base 'Pegex::Grammar';
 
-use constant file => '../jsony-pgx/jsony.pgx';
+use constant file => './share/jsony.pgx';
 
-sub make_tree {
+sub make_tree {   # Generated/Inlined by Pegex::Grammar (0.57)
   {
     '+grammar' => 'jsony',
     '+toprule' => 'jsony',
@@ -12,13 +12,13 @@ sub make_tree {
       '.rgx' => qr/\G\r?\n/
     },
     '_' => {
-      '.rgx' => qr/\G(?:\s|(?:\#\ .*\r?\n|\#\r?\n|\ *\r?\n))*/
+      '.rgx' => qr/\G(?:\s|(?:\#\ .*|\#|\ *)(?:\r?\n|\z))*/
     },
     'bare' => {
       '.rgx' => qr/\G([^\s\{\}\[\]'",]*[^\s\{\}\[\]'",:])/
     },
     'comment' => {
-      '.rgx' => qr/\G(?:\#\ .*\r?\n|\#\r?\n|\ *\r?\n)/
+      '.rgx' => qr/\G(?:\#\ .*|\#|\ *)(?:\r?\n|\z)/
     },
     'double' => {
       '.rgx' => qr/\G"((?:\\(?:["\\\/bfnrt]|u[0-9a-fA-F]{4})|[^"\x00-\x1f])*)"/
@@ -53,7 +53,7 @@ sub make_tree {
           '-flat' => 1,
           '.all' => [
             {
-              '.rgx' => qr/\G(?:\s|(?:\#\ .*\r?\n|\#\r?\n|\ *\r?\n))*,?(?:\s|(?:\#\ .*\r?\n|\#\r?\n|\ *\r?\n))*/
+              '.rgx' => qr/\G(?:\s|(?:\#\ .*|\#|\ *)(?:\r?\n|\z))*,?(?:\s|(?:\#\ .*|\#|\ *)(?:\r?\n|\z))*/
             },
             {
               '.ref' => 'node'
@@ -62,21 +62,21 @@ sub make_tree {
         },
         {
           '+max' => 1,
-          '.rgx' => qr/\G(?:\s|(?:\#\ .*\r?\n|\#\r?\n|\ *\r?\n))*,?(?:\s|(?:\#\ .*\r?\n|\#\r?\n|\ *\r?\n))*/
+          '.rgx' => qr/\G(?:\s|(?:\#\ .*|\#|\ *)(?:\r?\n|\z))*,?(?:\s|(?:\#\ .*|\#|\ *)(?:\r?\n|\z))*/
         }
       ]
     },
     'map' => {
       '.all' => [
         {
-          '.rgx' => qr/\G(?:\s|(?:\#\ .*\r?\n|\#\r?\n|\ *\r?\n))*\{(?:\s|(?:\#\ .*\r?\n|\#\r?\n|\ *\r?\n))*/
+          '.rgx' => qr/\G(?:\s|(?:\#\ .*|\#|\ *)(?:\r?\n|\z))*\{(?:\s|(?:\#\ .*|\#|\ *)(?:\r?\n|\z))*/
         },
         {
           '+min' => 0,
           '.ref' => 'pair'
         },
         {
-          '.rgx' => qr/\G(?:\s|(?:\#\ .*\r?\n|\#\r?\n|\ *\r?\n))*\}(?:\s|(?:\#\ .*\r?\n|\#\r?\n|\ *\r?\n))*/
+          '.rgx' => qr/\G(?:\s|(?:\#\ .*|\#|\ *)(?:\r?\n|\z))*\}(?:\s|(?:\#\ .*|\#|\ *)(?:\r?\n|\z))*/
         }
       ]
     },
@@ -99,13 +99,13 @@ sub make_tree {
           '.ref' => 'string'
         },
         {
-          '.rgx' => qr/\G(?:\s|(?:\#\ .*\r?\n|\#\r?\n|\ *\r?\n))*:?(?:\s|(?:\#\ .*\r?\n|\#\r?\n|\ *\r?\n))*/
+          '.rgx' => qr/\G(?:\s|(?:\#\ .*|\#|\ *)(?:\r?\n|\z))*:?(?:\s|(?:\#\ .*|\#|\ *)(?:\r?\n|\z))*/
         },
         {
           '.ref' => 'node'
         },
         {
-          '.rgx' => qr/\G(?:\s|(?:\#\ .*\r?\n|\#\r?\n|\ *\r?\n))*,?(?:\s|(?:\#\ .*\r?\n|\#\r?\n|\ *\r?\n))*/
+          '.rgx' => qr/\G(?:\s|(?:\#\ .*|\#|\ *)(?:\r?\n|\z))*,?(?:\s|(?:\#\ .*|\#|\ *)(?:\r?\n|\z))*/
         }
       ]
     },
@@ -125,7 +125,7 @@ sub make_tree {
     'seq' => {
       '.all' => [
         {
-          '.rgx' => qr/\G(?:\s|(?:\#\ .*\r?\n|\#\r?\n|\ *\r?\n))*\[(?:\s|(?:\#\ .*\r?\n|\#\r?\n|\ *\r?\n))*/
+          '.rgx' => qr/\G(?:\s|(?:\#\ .*|\#|\ *)(?:\r?\n|\z))*\[(?:\s|(?:\#\ .*|\#|\ *)(?:\r?\n|\z))*/
         },
         {
           '+max' => 1,
@@ -138,7 +138,7 @@ sub make_tree {
               '-flat' => 1,
               '.all' => [
                 {
-                  '.rgx' => qr/\G(?:\s|(?:\#\ .*\r?\n|\#\r?\n|\ *\r?\n))*,?(?:\s|(?:\#\ .*\r?\n|\#\r?\n|\ *\r?\n))*/
+                  '.rgx' => qr/\G(?:\s|(?:\#\ .*|\#|\ *)(?:\r?\n|\z))*,?(?:\s|(?:\#\ .*|\#|\ *)(?:\r?\n|\z))*/
                 },
                 {
                   '.ref' => 'node'
@@ -147,12 +147,12 @@ sub make_tree {
             },
             {
               '+max' => 1,
-              '.rgx' => qr/\G(?:\s|(?:\#\ .*\r?\n|\#\r?\n|\ *\r?\n))*,?(?:\s|(?:\#\ .*\r?\n|\#\r?\n|\ *\r?\n))*/
+              '.rgx' => qr/\G(?:\s|(?:\#\ .*|\#|\ *)(?:\r?\n|\z))*,?(?:\s|(?:\#\ .*|\#|\ *)(?:\r?\n|\z))*/
             }
           ]
         },
         {
-          '.rgx' => qr/\G(?:\s|(?:\#\ .*\r?\n|\#\r?\n|\ *\r?\n))*\](?:\s|(?:\#\ .*\r?\n|\#\r?\n|\ *\r?\n))*/
+          '.rgx' => qr/\G(?:\s|(?:\#\ .*|\#|\ *)(?:\r?\n|\z))*\](?:\s|(?:\#\ .*|\#|\ *)(?:\r?\n|\z))*/
         }
       ]
     },
@@ -169,7 +169,7 @@ sub make_tree {
           '.ref' => 'string'
         },
         {
-          '.rgx' => qr/\G(?:\s|(?:\#\ .*\r?\n|\#\r?\n|\ *\r?\n))*:(?:\s|(?:\#\ .*\r?\n|\#\r?\n|\ *\r?\n))*/
+          '.rgx' => qr/\G(?:\s|(?:\#\ .*|\#|\ *)(?:\r?\n|\z))*:(?:\s|(?:\#\ .*|\#|\ *)(?:\r?\n|\z))*/
         },
         {
           '.ref' => 'node'
@@ -186,7 +186,7 @@ sub make_tree {
     'top_seq_entry' => {
       '.all' => [
         {
-          '.rgx' => qr/\G(?:\s|(?:\#\ .*\r?\n|\#\r?\n|\ *\r?\n))*\-\ +/
+          '.rgx' => qr/\G(?:\s|(?:\#\ .*|\#|\ *)(?:\r?\n|\z))*\-\ +/
         },
         {
           '.all' => [
@@ -201,7 +201,7 @@ sub make_tree {
                   '-flat' => 1,
                   '.all' => [
                     {
-                      '.rgx' => qr/\G(?:\ *,\ *\r?\n(?:\s|(?:\#\ .*\r?\n|\#\r?\n|\ *\r?\n))*|\ +)/
+                      '.rgx' => qr/\G(?:\ *,\ *\r?\n(?:\s|(?:\#\ .*|\#|\ *)(?:\r?\n|\z))*|\ +)/
                     },
                     {
                       '.ref' => 'node'
@@ -210,7 +210,7 @@ sub make_tree {
                 },
                 {
                   '+max' => 1,
-                  '.rgx' => qr/\G(?:\ *,\ *\r?\n(?:\s|(?:\#\ .*\r?\n|\#\r?\n|\ *\r?\n))*|\ +)/
+                  '.rgx' => qr/\G(?:\ *,\ *\r?\n(?:\s|(?:\#\ .*|\#|\ *)(?:\r?\n|\z))*|\ +)/
                 }
               ]
             },
